@@ -4,10 +4,10 @@
 
 echo $
 if [ "$(echo "intel123" | sudo docker ps -q -f name=^cadvisor$)" ]; then
-    echo "Docker-Telemetry already running"
+    echo -e "\e[1;32m\nDocker-Telemetry already running\e[0m"
     echo -e "To stop run command: '\e[1;3;4;33mdc app-services docker-telemetry stop  $1\e[0m'"
 else
-    echo "Installing Docker-Telemetry service"
+    echo -e "\e[1;32m\nInstalling Docker-Telemetry service\e[0m"
     export HOST_IP=$(hostname -I | cut -d' ' -f1)
     ver=$(python3 --version | grep Python | awk '{print $2}' | xargs printf '%0.1f\n')
     if [ $1=="all-services" ]; then      
