@@ -20,7 +20,7 @@ if !(git clone -b 2022.1.0 https://github.com/openvinotoolkit/openvino.git) then
 else
     echo -e "\e[1;32mSuccess\e[0m"
     cd openvino/tools/pot/
-    python3 setup.py install
+    sudo python3 setup.py install
     echo -e "\e[1;32mpot is installed\e[0m"
 fi
 
